@@ -143,11 +143,12 @@ our $PKGNAME_REGEX = qr/[a-z0-9][-+\.a-z0-9]+/o;
 =item $PKGREPACK_REGEX
 
 Regular expression that matches "repacked" package names.  The expression is
-not anchored and does not enforce any "boundary" characters.
+not anchored and does not enforce any "boundary" characters. It should only
+be applied to the upstream portion (see #931846).
 
 =cut
 
-our $PKGREPACK_REGEX = qr/(dfsg|debian|ds|repack)[^-]*\-[^-]+$/o;
+our $PKGREPACK_REGEX = qr/(dfsg|debian|ds|repack)/o;
 
 =item $PKGVERSION_REGEX
 
